@@ -1,5 +1,5 @@
 /* session.c --- Data integrity/privacy protection of DIGEST-MD5.
- * Copyright (C) 2002, 2003, 2004, 2005  Simon Josefsson
+ * Copyright (C) 2002-2012 Simon Josefsson
  *
  * This file is part of GNU SASL Library.
  *
@@ -20,7 +20,7 @@
  *
  */
 
-#if HAVE_CONFIG_H
+#ifdef HAVE_CONFIG_H
 # include "config.h"
 #endif
 
@@ -113,10 +113,10 @@ digest_md5_encode (const char *input, size_t input_len,
   return 0;
 }
 
-#define C2I(buf) ((buf[0] & 0xFF) |		\
-		  ((buf[1] & 0xFF) << 8) |	\
-		  ((buf[2] & 0xFF) << 16) |	\
-		  ((buf[3] & 0xFF) << 24))
+#define C2I(buf) ((buf[3] & 0xFF) |		\
+		  ((buf[2] & 0xFF) << 8) |	\
+		  ((buf[1] & 0xFF) << 16) |	\
+		  ((buf[0] & 0xFF) << 24))
 
 int
 digest_md5_decode (const char *input, size_t input_len,
