@@ -1,5 +1,5 @@
 /* test-parser.c --- Self tests of DIGEST-MD5 parser & printer.
- * Copyright (C) 2004, 2006, 2008  Simon Josefsson
+ * Copyright (C) 2004-2012 Simon Josefsson
  *
  * This file is part of GNU SASL Library.
  *
@@ -28,6 +28,8 @@
 #include "printer.h"
 #include "digesthmac.h"
 
+#include "gc.h"
+
 int
 main (int argc, char *argv[])
 {
@@ -40,7 +42,7 @@ main (int argc, char *argv[])
   char *tmp;
 
   {
-    char *token = "nonce=4711, foo=bar, algorithm=md5-sess";
+    const char *token = "nonce=4711, foo=bar, algorithm=md5-sess";
 
     printf ("challenge `%s': ", token);
     rc = digest_md5_parse_challenge (token, 0, &c);
@@ -57,7 +59,7 @@ main (int argc, char *argv[])
   }
 
   {
-    char *token = "qop=\"auth, auth-conf\", nonce=42, algorithm=md5-sess";
+    const char *token = "qop=\"auth, auth-conf\", nonce=42, algorithm=md5-sess";
 
     printf ("challenge `%s': ", token);
     rc = digest_md5_parse_challenge (token, 0, &c);
@@ -67,7 +69,7 @@ main (int argc, char *argv[])
   }
 
   {
-    char *token = "cipher=\"des\", nonce=42, algorithm=md5-sess";
+    const char *token = "cipher=\"des\", nonce=42, algorithm=md5-sess";
 
     printf ("challenge `%s': ", token);
     rc = digest_md5_parse_challenge (token, 0, &c);
@@ -77,8 +79,8 @@ main (int argc, char *argv[])
   }
 
   {
-    char *token = "qop=\"auth, auth-conf\", nonce=42, algorithm=md5-sess, "
-      "cipher=\"des\"";
+    const char *token = "qop=\"auth, auth-conf\", nonce=42, "
+      "algorithm=md5-sess, cipher=\"des\"";
 
     printf ("challenge `%s': ", token);
     rc = digest_md5_parse_challenge (token, 0, &c);
@@ -94,7 +96,7 @@ main (int argc, char *argv[])
   }
 
   {
-    char *token = "bar=foo, foo=bar";
+    const char *token = "bar=foo, foo=bar";
 
     printf ("challenge `%s': ", token);
     rc = digest_md5_parse_challenge (token, 0, &c);
@@ -104,7 +106,7 @@ main (int argc, char *argv[])
   }
 
   {
-    char *token = "realm=foo, realm=bar, nonce=42, algorithm=md5-sess";
+    const char *token = "realm=foo, realm=bar, nonce=42, algorithm=md5-sess";
 
     printf ("challenge `%s': ", token);
     rc = digest_md5_parse_challenge (token, 0, &c);
@@ -123,7 +125,7 @@ main (int argc, char *argv[])
   /* Response */
 
   {
-    char *token = "bar=foo, foo=bar";
+    const char *token = "bar=foo, foo=bar";
 
     printf ("response `%s': ", token);
     rc = digest_md5_parse_response (token, 0, &r);
@@ -133,7 +135,7 @@ main (int argc, char *argv[])
   }
 
   {
-    char *token = "username=jas, nonce=42, cnonce=4711, nc=00000001, "
+    const char *token = "username=jas, nonce=42, cnonce=4711, nc=00000001, "
       "digest-uri=foo, response=01234567890123456789012345678901";
 
     printf ("response `%s': ", token);
@@ -153,7 +155,7 @@ main (int argc, char *argv[])
   /* Auth-response, finish. */
 
   {
-    char *token = "rspauth=\"6a204da26b9888ee40bb3052ff056a67\"";
+    const char *token = "rspauth=\"6a204da26b9888ee40bb3052ff056a67\"";
 
     printf ("finish `%s': ", token);
     rc = digest_md5_parse_finish (token, 0, &f);
@@ -165,7 +167,7 @@ main (int argc, char *argv[])
   }
 
   {
-    char *token = "bar=foo, foo=bar";
+    const char *token = "bar=foo, foo=bar";
 
     printf ("finish `%s': ", token);
     rc = digest_md5_parse_finish (token, 0, &f);
@@ -174,6 +176,10 @@ main (int argc, char *argv[])
     printf ("invalid? PASS\n");
   }
 
+  rc = gc_init ();
+  if (rc != 0)
+    abort ();
+
   memset (buf16, 'Q', 16);
 
   rc = digest_md5_hmac (buf32, buf16, "nonce", 1, "cnonce",
