@@ -1,5 +1,5 @@
 /* client.c --- SAML20 mechanism, client side.
- * Copyright (C) 2010  Simon Josefsson
+ * Copyright (C) 2010-2012  Simon Josefsson
  *
  * This file is part of GNU SASL Library.
  *
@@ -73,7 +73,6 @@ _gsasl_saml20_client_step (Gsasl_session * sctx,
       {
 	const char *authzid = gsasl_property_get (sctx, GSASL_AUTHZID);
 	const char *p;
-	int len;
 
 	p = gsasl_property_get (sctx, GSASL_SAML20_IDP_IDENTIFIER);
 	if (!p || !*p)
@@ -82,7 +81,7 @@ _gsasl_saml20_client_step (Gsasl_session * sctx,
 	res = _gsasl_gs2_generate_header (false, 'n', NULL, authzid,
 					  strlen (p), p,
 					  output, output_len);
-	if (res == GSASL_OK)
+	if (res != GSASL_OK)
 	  return res;
 
 	res = GSASL_NEEDS_MORE;
