@@ -112,8 +112,12 @@ map (Gsasl_session * sctx, Gsasl_property prop)
       p = &sctx->saml20_redirect_url;
       break;
 
-    case GSASL_OPENID20_AUTH_IDENTIFIER:
-      p = &sctx->openid20_auth_identifier;
+    case GSASL_OPENID20_REDIRECT_URL:
+      p = &sctx->openid20_redirect_url;
+      break;
+
+    case GSASL_OPENID20_OUTCOME_DATA:
+      p = &sctx->openid20_outcome_data;
       break;
 
       /* If you add anything here, remember to change change
