@@ -229,6 +229,8 @@ step_send (const char *data)
   return 1;
 }
 
+/* Return 1 on token, 2 on protocol success, 3 on protocol fail, 0 on
+   errors. */
 static int
 step_recv (char **data)
 {
@@ -243,17 +245,6 @@ step_recv (char **data)
   return 1;
 }
 
-static int
-auth_finish (void)
-{
-  if (args_info.imap_flag)
-    return imap_auth_finish ();
-  if (args_info.smtp_flag)
-    return smtp_auth_finish ();
-
-  return 1;
-}
-
 static int
 logout (void)
 {
@@ -449,9 +440,6 @@ main (int argc, char *argv[])
 
   if (args_info.connect_given || args_info.inputs_num > 0)
     {
-      struct sockaddr connect_addr;
-      struct sockaddr *saddr = &connect_addr;
-      size_t saddrlen = sizeof (*saddr);
       struct addrinfo hints;
       struct addrinfo *ai0, *ai;
 
@@ -490,9 +478,6 @@ main (int argc, char *argv[])
       if (sockfd < 0)
 	error (EXIT_FAILURE, errno, "socket");
 
-      saddr = ai->ai_addr;
-      saddrlen = ai->ai_addrlen;
-
       freeaddrinfo (ai);
     }
 
@@ -607,6 +592,7 @@ main (int argc, char *argv[])
 	}
 
 #if HAVE_GNUTLS_SESSION_CHANNEL_BINDING
+      if (!args_info.no_cb_flag)
 	{
 	  gnutls_datum cb;
 
@@ -675,6 +661,8 @@ main (int argc, char *argv[])
 
       do
 	{
+	  int res2;
+
 	  res = gsasl_step64 (xctx, in, &out);
 	  if (res != GSASL_NEEDS_MORE && res != GSASL_OK)
 	    break;
@@ -682,9 +670,6 @@ main (int argc, char *argv[])
 	  if (!step_send (out))
 	    return 1;
 
-	  if (res != GSASL_NEEDS_MORE)
-	    break;
-
 	no_client_first:
 	  if (!args_info.quiet_given &&
 	      !args_info.imap_flag && !args_info.smtp_flag)
@@ -697,18 +682,23 @@ main (int argc, char *argv[])
 				   "from server (press RET if none):\n"));
 	    }
 
-	  if (!step_recv (&in))
+	  /* Return 1 on token, 2 on protocol success, 3 on protocol fail, 0 on
+	     errors. */
+	  res2 = step_recv (&in);
+	  if (!res2)
 	    return 1;
+	  if (res2 == 3)
+	    error (EXIT_FAILURE, 0, _("server error"));
+	  if (res2 == 2)
+	    break;
 	}
-      while (res == GSASL_NEEDS_MORE);
+      while (args_info.imap_flag || args_info.smtp_flag
+	     || res == GSASL_NEEDS_MORE);
 
       if (res != GSASL_OK)
 	error (EXIT_FAILURE, 0, _("mechanism error: %s"),
 	       gsasl_strerror (res));
 
-      if (!auth_finish ())
-	return 1;
-
       if (!args_info.quiet_given)
 	{
 	  if (args_info.server_flag)
